@@ -5,7 +5,7 @@
 
     Frontends for the message extraction functionality.
 
-    :copyright: (c) 2013 by the Babel Team.
+    :copyright: (c) 2013-2018 by the Babel Team.
     :license: BSD, see LICENSE for more details.
 """
 from __future__ import print_function
@@ -22,7 +22,7 @@ from locale import getpreferredencoding
 
 from babel import __version__ as VERSION
 from babel import Locale, localedata
-from babel._compat import StringIO, string_types, text_type
+from babel._compat import StringIO, string_types, text_type, PY2
 from babel.core import UnknownLocaleError
 from babel.messages.catalog import Catalog
 from babel.messages.extract import DEFAULT_KEYWORDS, DEFAULT_MAPPING, check_and_call_extract_file, extract_from_dir
@@ -39,6 +39,9 @@ except ImportError:
     from configparser import RawConfigParser
 
 
+po_file_read_mode = ('rU' if PY2 else 'r')
+
+
 def listify_value(arg, split=None):
     """
     Make a list out of an argument.
@@ -391,7 +394,7 @@ class extract_messages(Command):
 
         if self.input_paths:
             if isinstance(self.input_paths, string_types):
-                self.input_paths = re.split(',\s*', self.input_paths)
+                self.input_paths = re.split(r',\s*', self.input_paths)
         elif self.distribution is not None:
             self.input_paths = dict.fromkeys([
                 k.split('.', 1)[0]
@@ -485,7 +488,7 @@ class extract_messages(Command):
         mappings = []
 
         if self.mapping_file:
-            with open(self.mapping_file, 'U') as fileobj:
+            with open(self.mapping_file, po_file_read_mode) as fileobj:
                 method_map, options_map = parse_mapping(fileobj)
             for path in self.input_paths:
                 mappings.append((path, method_map, options_map))
@@ -963,7 +966,12 @@ def parse_mapping(fileobj, filename=None):
 
     parser = RawConfigParser()
     parser._sections = odict(parser._sections)  # We need ordered sections
-    parser.readfp(fileobj, filename)
+
+    if PY2:
+        parser.readfp(fileobj, filename)
+    else:
+        parser.read_file(fileobj, filename)
+
     for section in parser.sections():
         if section == 'extractors':
             extractors = dict(parser.items(section))
@@ -978,7 +986,7 @@ def parse_mapping(fileobj, filename=None):
                 method = extractors[method]
             method_map[idx] = (pattern, method)
 
-    return (method_map, options_map)
+    return method_map, options_map
 
 
 def parse_keywords(strings=[]):
